from functools import reduce
from datetime import datetime


def mark_parameters_in_message(message: str, *parameters) -> str:
    return (
        message.replace("{}", "\033[97m{}\033[0m").format(*parameters)
        if parameters
        else message
    )


def log(message, *parameters):
    print(
        f"[\033[2m{datetime.now():%Y-%m-%d %H:%M:%S}\033[0m] {mark_parameters_in_message(message, *parameters)}"
    )


def warning(message, *parameters):
    print(
        f"[\033[2m{datetime.now():%Y-%m-%d %H:%M:%S}\033[0m] \033[33mWarning:\033[0m {mark_parameters_in_message(message, *parameters)}"
    )


def log_error(message, *parameters):
    print(
        f"[\033[2m{datetime.now():%Y-%m-%d %H:%M:%S}\033[0m] \033[31mError:\033[0m {mark_parameters_in_message(message, *parameters)}"
    )


def compose(*functions):
    return reduce(lambda f, g: lambda x: f(g(x)), functions)



import os
from setuptools import setup


def read(file_name):
    return open(os.path.join(os.path.dirname(__file__), file_name)).read()


setup(
    version=read("version"),
    name="podcast_downloader",
    author="Dawid Plocki",
    author_email="dawid.plocki@gmail.com",
    description="The script for downloading the recent mp3 from given RSS channels",
    long_description_content_type="text/markdown",
    long_description=read("README.md"),
    packages=["podcast_downloader"],
    install_requires=["feedparser"],
    url="https://github.com/dplocki/podcast-downloader",
    classifiers=[
        "Environment :: Console",
        "License :: OSI Approved :: GNU General Public License v3 (GPLv3)",
        "Natural Language :: English",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3.7",
    ],
    python_requires=">=3.6",
)
